@@ -9,6 +9,7 @@ import tempfile
 import time
 import uuid
 from contextlib import contextmanager, suppress
+from enum import Enum
 from pathlib import Path
 from typing import Mapping, Optional, Union
 
@@ -17,10 +18,10 @@ from packaging.version import Version
 from pymobiledevice3 import usbmux
 from pymobiledevice3.ca import ca_do_everything
 from pymobiledevice3.common import get_home_folder
-from pymobiledevice3.exceptions import CannotStopSessionError, ConnectionFailedError, ConnectionTerminatedError, \
-    FatalPairingError, IncorrectModeError, InvalidHostIDError, InvalidServiceError, LockdownError, MissingValueError, \
-    NotPairedError, PairingDialogResponsePendingError, PairingError, PasscodeRequiredError, PasswordRequiredError, \
-    SetProhibitedError, StartServiceError, UserDeniedPairingError
+from pymobiledevice3.exceptions import CannotStopSessionError, ConnectionTerminatedError, FatalPairingError, \
+    IncorrectModeError, InvalidHostIDError, InvalidServiceError, LockdownError, MissingValueError, NotPairedError, \
+    PairingDialogResponsePendingError, PairingError, PasswordRequiredError, SetProhibitedError, StartServiceError, \
+    UserDeniedPairingError
 from pymobiledevice3.irecv_devices import IRECV_DEVICES
 from pymobiledevice3.service_connection import Medium, ServiceConnection
 from pymobiledevice3.usbmux import PlistMuxConnection
@@ -95,6 +96,15 @@ DOMAINS = ['com.apple.disk_usage',
            'com.apple.Accessibility', ]
 
 
+class DeviceClass(Enum):
+    IPHONE = 'iPhone'
+    IPAD = 'iPad'
+    IPOD = 'iPod'
+    WATCH = 'Watch'
+    APPLE_TV = 'AppleTV'
+    UNKNOWN = 'Unknown'
+
+
 class LockdownClient(object):
     DEFAULT_CLIENT_NAME = 'pymobiledevice3'
     SERVICE_PORT = 62078
@@ -188,6 +198,13 @@ class LockdownClient(object):
     def query_type(self) -> str:
         return self._request('QueryType').get('Type')
 
+    @property
+    def device_class(self) -> DeviceClass:
+        try:
+            return DeviceClass(self.all_values.get('DeviceClass'))
+        except ValueError:
+            return DeviceClass('Unknown')
+
     @property
     def wifi_mac_address(self) -> str:
         return self.all_values.get('WiFiAddress')
@@ -232,17 +249,6 @@ class LockdownClient(object):
     def invert_display(self, value: bool) -> None:
         self.set_value(int(value), 'com.apple.Accessibility', 'InvertDisplayEnabledByiTunes')
 
-    @property
-    def enable_wifi_pairing(self) -> bool:
-        return self.get_value('com.apple.mobile.wireless_lockdown').get('EnableWifiPairing', False)
-
-    @enable_wifi_pairing.setter
-    def enable_wifi_pairing(self, value: bool) -> None:
-        try:
-            self.set_value(value, 'com.apple.mobile.wireless_lockdown', 'EnableWifiPairing')
-        except MissingValueError as e:
-            raise PasscodeRequiredError from e
-
     @property
     def enable_wifi_connections(self) -> bool:
         return self.get_value('com.apple.mobile.wireless_lockdown').get('EnableWifiConnections', False)
@@ -367,7 +373,7 @@ class LockdownClient(object):
         if self.pair_record is None:
             return False
 
-        if Version(self.product_version) < Version('11.0'):
+        if (Version(self.product_version) < Version('7.0')) and (self.device_class != DeviceClass.WATCH):
             try:
                 self._request('ValidatePair', {'PairRecord': self.pair_record})
             except PairingError:
@@ -416,7 +422,11 @@ class LockdownClient(object):
         pair = self._request_pair(pair_options, timeout=timeout)
 
         pair_record['HostPrivateKey'] = private_key_pem
-        pair_record['EscrowBag'] = pair.get('EscrowBag')
+        escrow_bag = pair.get('EscrowBag')
+
+        if escrow_bag is not None:
+            pair_record['EscrowBag'] = pair.get('EscrowBag')
+
         self.pair_record = pair_record
         self._write_storage_file(f'{self.identifier}.plist', plistlib.dumps(pair_record))
 
@@ -518,7 +528,7 @@ class LockdownClient(object):
     def start_developer_service(self, name, escrow_bag=None) -> ServiceConnection:
         try:
             return self.start_service(name, escrow_bag)
-        except (StartServiceError, ConnectionFailedError):
+        except StartServiceError:
             self.logger.error(
                 'Failed to connect to required service. Make sure DeveloperDiskImage.dmg has been mounted. '
                 'You can do so using: pymobiledevice3 mounter mount'
