@@ -1,19 +1,17 @@
-import logging
 import plistlib
 import typing
 
 from pymobiledevice3.lockdown import LockdownClient
+from pymobiledevice3.services.base_service import BaseService
 
 CHUNK_SIZE = 200
 
 
-class DebugServerAppList(object):
+class DebugServerAppList(BaseService):
     SERVICE_NAME = 'com.apple.debugserver.DVTSecureSocketProxy.applist'
 
     def __init__(self, lockdown: LockdownClient):
-        self.logger = logging.getLogger(__name__)
-        self.lockdown = lockdown
-        self.service = self.lockdown.start_developer_service(self.SERVICE_NAME)
+        super().__init__(lockdown, self.SERVICE_NAME)
 
     def get(self) -> typing.Mapping:
         buf = b''
