@@ -3,13 +3,13 @@ import plistlib
 import typing
 from functools import partial
 from pprint import pprint
-from queue import Queue, Empty
+from queue import Empty, Queue
 
 import IPython
 from bpylist2 import archiver
-from construct import Struct, Default, Int64ul, Prefixed, GreedyRange, Select, Const, Int32ul, Switch, this, \
-    GreedyBytes, Adapter, Int16ul, Int32sl
-from pygments import highlight, lexers, formatters
+from construct import Adapter, Const, Default, GreedyBytes, GreedyRange, Int16ul, Int32sl, Int32ul, Int64ul, Prefixed, \
+    Select, Struct, Switch, this
+from pygments import formatters, highlight, lexers
 
 from pymobiledevice3.exceptions import DvtException, UnrecognizedSelectorError
 from pymobiledevice3.lockdown import LockdownClient
